@@ -1,6 +1,6 @@
 /* b-complain.c --- various ways of writing to standard error
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
 
    This file is part of GNU RCS.
 
@@ -22,9 +22,6 @@
 #include <stdarg.h>
 #include <errno.h>
 
-/* Apparently gnulib needs this, sigh.  */
-char *program_name;
-
 void
 unbuffer_standard_error (void)
 {
@@ -116,7 +113,7 @@ static void
 die (void)
 {
   complain ("%s aborted\n", PROGRAM (name));
-  PROGRAM (exiterr) ();
+  BOW_OUT ();
 }
 
 void
