@@ -1,6 +1,6 @@
 /* b-complain.h --- various ways of writing to standard error
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
 
    This file is part of GNU RCS.
 
@@ -18,9 +18,6 @@
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-/* Apparently gnulib needs this, sigh.  */
-extern char *program_name;
-
 extern void unbuffer_standard_error (void);
 extern void vcomplain (char const *fmt, va_list args);
 extern void complain (char const *fmt, ...)
