@@ -1,6 +1,6 @@
 /* b-divvy.c --- dynamic memory manglement
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
 
    This file is part of GNU RCS.
 
@@ -29,12 +29,20 @@
 struct divvy *plexus;
 struct divvy *single;
 
-void
+static void
 oom (void)
 {
   PFATAL ("out of memory");
 }
 
+void *
+okalloc (void * p)
+{
+  if (!p)
+    oom ();
+  return p;
+}
+
 static void *
 allocate (size_t size, bool clearp)
 {
@@ -165,10 +173,7 @@ accumulate_byte (struct divvy *divvy, int c)
 void
 accumulate_range (struct divvy *divvy, char const *beg, char const *end)
 {
-  struct obstack *o = divvy->space;
-
-  while (beg < end)
-    obstack_1grow (o, *beg++);
+  obstack_grow (divvy->space, beg, end - beg);
 }
 
 char *
