@@ -1,6 +1,6 @@
 /* b-divvy.h --- dynamic memory manglement
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
 
    This file is part of GNU RCS.
 
@@ -29,7 +29,7 @@ struct divvy
 extern struct divvy *plexus;
 extern struct divvy *single;
 
-extern void oom (void);
+extern void *okalloc (void *p);
 extern struct divvy *make_space (char const name[]);
 extern void *alloc (struct divvy *divvy, char const *what, size_t len);
 extern void *zlloc (struct divvy *divvy, char const *what, size_t len);
