@@ -1,6 +1,6 @@
 /* b-isr.c --- interrupt service routine
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -59,7 +59,7 @@ werr (char const *s)
     return;
 
   if (len != write (STDERR_FILENO, s, len))
-    PROGRAM (exiterr) ();
+    BOW_OUT ();
 }
 
 void
@@ -132,7 +132,7 @@ catchsigaction (int signo, siginfo_t *info, RCS_UNUSED void *uc)
       /* If this signal was planned, don't complain about it.  */
       if (!(from_mmap && ISR (access_name)))
         {
-          char *nRCS = "\nRCS";
+          const char *nRCS = "\nRCS";
 
           if (from_mmap && info && info->si_errno)
             {
@@ -159,7 +159,7 @@ catchsigaction (int signo, siginfo_t *info, RCS_UNUSED void *uc)
         }
       werr ("Cleaning up.\n");
     }
-  PROGRAM (exiterr) ();
+  BOW_OUT ();
 }
 
 #ifndef SA_ONSTACK
