@@ -1,6 +1,6 @@
 /* RCS common definitions and data structures
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -40,15 +40,15 @@
 #include <vfork.h>
 #endif
 
+#define exiting  _Noreturn
+
 /* GCC attributes  */
 
 #define RCS_UNUSED  _GL_UNUSED
 
 #if __GNUC__ >= 3 || (__GNUC__ == 2 && __GNUC_MINOR__ >= 7)
-#define exiting              __attribute__ ((__noreturn__))
 #define printf_string(m, n)  __attribute__ ((__format__ (printf, m, n)))
 #else
-#define exiting
 #define printf_string(m, n)
 #endif
 
@@ -388,8 +388,8 @@ struct program
   char const *name;
   /* Text for --help.  */
   char const *help;
-  /* Exit errorfully.  */
-  void (*exiterr) (void) exiting;
+  /* What to do when exiting errorfully (see TYAG_* below).  */
+  int const tyag;
 };
 
 /* (Somewhat) fleeting files.  */
@@ -826,10 +826,15 @@ char const *date2str (char const date[datesize],
                       char datebuf[datesize + zonelenmax]);
 
 /* rcsutil */
-void exit_failurefully (void)
-  exiting;
-void exit_diff_trouble (void)
+void thank_you_and_goodnight (int const how)
   exiting;
+/* These are for ‘thank_you_and_goodnight’.  */
+#define TYAG_ORCSERROR     (1 << 3)
+#define TYAG_DIRTMPUNLINK  (1 << 2)
+#define TYAG_TEMPUNLINK    (1 << 1)
+#define TYAG_DIFF          (1 << 0)
+#define TYAG_IMMEDIATE           0
+
 void gnurcs_init (struct program const *program);
 void gnurcs_goodbye (void);
 void bad_option (char const *option);
@@ -853,6 +858,12 @@ int getRCSINIT (int argc, char **argv, char ***newargv);
 
 /* Idioms.  */
 
+#define BOG_DIFF   (TYAG_TEMPUNLINK | TYAG_DIFF)
+#define BOG_ZONK   (TYAG_DIRTMPUNLINK | TYAG_TEMPUNLINK)
+#define BOG_FULL   (TYAG_ORCSERROR | BOG_ZONK)
+
+#define BOW_OUT()  thank_you_and_goodnight (PROGRAM (tyag))
+
 /* Murphy was an optimist...  */
 #define PROB(x)  (0 > (x))
 
@@ -899,4 +910,7 @@ int getRCSINIT (int argc, char **argv, char ***newargv);
 #define MEM_SAME(n,a,b)  (0 == memcmp ((a), (b), (n)))
 #define MEM_DIFF(n,a,b)  (0 != memcmp ((a), (b), (n)))
 
+#define ODDP(n)   ((n) & 1)
+#define EVENP(n)  (! ODDP (n))
+
 /* base.h ends here */
