@@ -1,6 +1,6 @@
 /* Check in revisions of RCS files from working files.
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -80,15 +80,6 @@ cleanup (void)
   dirtempunlink ();
 }
 
-static exiting void
-exiterr (void)
-{
-  ORCSerror ();
-  dirtempunlink ();
-  tempunlink ();
-  exit_failurefully ();
-}
-
 #define ACCF(...)  accf (PLEXUS, __VA_ARGS__)
 
 #define OK(x)     (x)->string = finish_string (PLEXUS, &((x)->size))
@@ -167,14 +158,14 @@ static struct wlink newbranch;          /* new branch to be inserted */
 
 static int
 addbranch (struct delta *branchpoint, struct cbuf *num,
-           bool removedlock, struct wlink **tp_deltas)
+           int removedlock, struct wlink **tp_deltas)
 /* Add a new branch and branch delta at ‘branchpoint’.
    If ‘num’ is the null string, append the new branch, incrementing
    the highest branch number (initially 1), and setting the level number to 1.
    The new delta and branchhead are in globals ‘newdelta’ and ‘newbranch’, resp.
    The new number is placed into a ‘PLEXUS’ string with ‘num’ pointing to it.
    Return -1 on error, 1 if a lock is removed, 0 otherwise.
-   If ‘removedlock’, a lock was already removed.  */
+   If ‘removedlock’ is 1, a lock was already removed.  */
 {
   struct wlink **btrail;
   struct delta *d;
@@ -192,7 +183,7 @@ addbranch (struct delta *branchpoint, struct cbuf *num,
           JAM (num, branchpoint->num);
           ADD (num, ".1.1");
         }
-      else if (numlength & 1)
+      else if (ODDP (numlength))
         ADD (num, ".1");
       newbranch.next = NULL;
 
@@ -213,7 +204,7 @@ addbranch (struct delta *branchpoint, struct cbuf *num,
   else
     {
       /* Place the branch properly.  */
-      field = numlength - ((numlength & 1) ^ 1);
+      field = numlength - EVENP (numlength);
       /* Field of branch number.  */
       btrail = &branchpoint->branches;
       while (d = (*btrail)->entry,
@@ -231,7 +222,7 @@ addbranch (struct delta *branchpoint, struct cbuf *num,
           /* Insert/append new branchhead.  */
           newbranch.next = *btrail;
           *btrail = &newbranch;
-          if (numlength & 1)
+          if (ODDP (numlength))
             ADD (num, ".1");
         }
       else
@@ -248,7 +239,7 @@ addbranch (struct delta *branchpoint, struct cbuf *num,
             }
           if (!removedlock && 0 <= (removedlock = removelock (targetdelta)))
             {
-              if (numlength & 1)
+              if (ODDP (numlength))
                 incnum (targetdelta->num, num);
               targetdelta->ilk = &newdelta;
               newdelta.ilk = NULL;
@@ -435,7 +426,7 @@ addelta (struct wlink **tp_deltas)
 
       /* Put new revision on side branch.  First, get branch point.  */
       tp = old.string;
-      for (i = newdnumlength - ((newdnumlength & 1) ^ 1); --i;)
+      for (i = newdnumlength - EVENP (newdnumlength); --i;)
         while (*tp++ != '.')
           continue;
       /* Ignore rest to get old delta.  */
@@ -530,7 +521,7 @@ xpandfile (struct fro *unexfile, struct delta const *delta,
       FINISH_EXPCTX (&ctx);
     }
   *exname = targetname;
-  return r & 1;
+  return ODDP (r);
 }
 
 /* --------------------- G E T L O G M S G --------------------------------*/
@@ -599,51 +590,6 @@ first_meaningful_symbolic_name (void)
   return ud->u.meaningful;
 }
 
-/*:help
-[options] file...
-Options:
-  -f[REV]       Force new entry, even if no content changed.
-  -I[REV]       Interactive.
-  -i[REV]       Initial checkin; error if RCS file already exists.
-  -j[REV]       Just checkin, don't init; error if RCS file does not exist.
-  -k[REV]       Compute revision from working file keywords.
-  -q[REV]       Quiet mode.
-  -r[REV]       Do normal checkin, if REV is specified;
-                otherwise, release lock and delete working file.
-  -l[REV]       Like -r, but immediately checkout locked (co -l) afterwards.
-  -u[REV]       Like -l, but checkout unlocked (co -u).
-  -M[REV]       Reset working file mtime (relevant for -l, -u).
-  -d[DATE]      Use DATE (or working file mtime).
-  -mMSG         Use MSG as the log message.
-  -nNAME        Assign symbolic NAME to the entry; NAME must be new.
-  -NNAME        Like -n, but overwrite any previous assignment.
-  -sSTATE       Set state to STATE.
-  -t-TEXT       Set description to TEXT.
-  -tFILENAME    Set description from text read from FILENAME.
-  -T            Set the RCS file's modification time to the new
-                revision's time if the former precedes the latter and there
-                is a new revision; preserve the RCS file's modification
-                time otherwise.
-  -V            Like --version.
-  -VN           Emulate RCS version N.
-  -wWHO         Use WHO as the author.
-  -xSUFF        Specify SUFF as a slash-separated list of suffixes
-                used to identify RCS file names.
-  -zZONE        Specify date output format in keyword-substitution
-                and also the default timezone for -dDATE.
-
-Multiple flags in {fiIjklMqru} may be used, except for -r, -l, -u, which are
-mutually exclusive.  If specified, REV can be symbolic, numeric, or mixed:
-  symbolic      Must have been defined previously (see -n, -N).
-  $             Determine from keyword values in the working file.
-  .N            Prepend default branch => DEFBR.N
-  BR.N          Use this, but N must be greater than any existing
-                on BR, or BR must be new.
-  BR            Latest rev on branch BR + 1 => BR.(L+1), or BR.1 if new branch.
-If REV is omitted, compute it from the last lock (co -l), perhaps
-starting a new branch.  If there is no lock, use DEFBR.(L+1).
-*/
-
 /* Use a variable instead of simple #define for fast identity compare.  */
 static char const default_state[] = DEFAULTSTATE;
 
@@ -675,8 +621,8 @@ main (int argc, char **argv)
     {
       .invoke = argv[0],
       .name = "ci",
-      .help = help,
-      .exiterr = exiterr
+      .help = ci_help,
+      .tyag = BOG_FULL
     };
 
   CHECK_HV ();
@@ -1162,9 +1108,9 @@ main (int argc, char **argv)
 
         if (PROB (donerewrite (changedRCS, !Ttimeflag
                                ? (time_t) - 1
-                               : from && wtime < (repo_stat->st_mtime
-                                                  ? repo_stat->st_mtime
-                                                  : wtime))))
+                               : ((from && wtime < repo_stat->st_mtime)
+                                  ? repo_stat->st_mtime
+                                  : wtime))))
           continue;
 
         if (!keepworkingfile)
@@ -1230,4 +1176,49 @@ main (int argc, char **argv)
   return exitstatus;
 }
 
+/*:help
+[options] file...
+Options:
+  -f[REV]       Force new entry, even if no content changed.
+  -I[REV]       Interactive.
+  -i[REV]       Initial checkin; error if RCS file already exists.
+  -j[REV]       Just checkin, don't init; error if RCS file does not exist.
+  -k[REV]       Compute revision from working file keywords.
+  -q[REV]       Quiet mode.
+  -r[REV]       Do normal checkin, if REV is specified;
+                otherwise, release lock and delete working file.
+  -l[REV]       Like -r, but immediately checkout locked (co -l) afterwards.
+  -u[REV]       Like -l, but checkout unlocked (co -u).
+  -M[REV]       Reset working file mtime (relevant for -l, -u).
+  -d[DATE]      Use DATE (or working file mtime).
+  -mMSG         Use MSG as the log message.
+  -nNAME        Assign symbolic NAME to the entry; NAME must be new.
+  -NNAME        Like -n, but overwrite any previous assignment.
+  -sSTATE       Set state to STATE.
+  -t-TEXT       Set description to TEXT.
+  -tFILENAME    Set description from text read from FILENAME.
+  -T            Set the RCS file's modification time to the new
+                revision's time if the former precedes the latter and there
+                is a new revision; preserve the RCS file's modification
+                time otherwise.
+  -V            Like --version.
+  -VN           Emulate RCS version N.
+  -wWHO         Use WHO as the author.
+  -xSUFF        Specify SUFF as a slash-separated list of suffixes
+                used to identify RCS file names.
+  -zZONE        Specify date output format in keyword-substitution
+                and also the default timezone for -dDATE.
+
+Multiple flags in {fiIjklMqru} may be used, except for -r, -l, -u, which are
+mutually exclusive.  If specified, REV can be symbolic, numeric, or mixed:
+  symbolic      Must have been defined previously (see -n, -N).
+  $             Determine from keyword values in the working file.
+  .N            Prepend default branch => DEFBR.N
+  BR.N          Use this, but N must be greater than any existing
+                on BR, or BR must be new.
+  BR            Latest rev on branch BR + 1 => BR.(L+1), or BR.1 if new branch.
+If REV is omitted, compute it from the last lock (co -l), perhaps
+starting a new branch.  If there is no lock, use DEFBR.(L+1).
+*/
+
 /* ci.c ends here */
