@@ -1,6 +1,6 @@
 /* Check out working files from revisions of RCS files.
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -84,15 +84,6 @@ cleanup (void)
   dirtempunlink ();
 }
 
-static exiting void
-exiterr (void)
-{
-  ORCSerror ();
-  dirtempunlink ();
-  tempunlink ();
-  exit_failurefully ();
-}
-
 static bool
 rmworkfile (void)
 /* Prepare to remove ‘MANI (filename)’, if it exists, and if it is read-only.
@@ -312,6 +303,10 @@ preparejoin (register char *j)
   return rv;
 }
 
+/* Elements in the constructed command line prior to this index are
+   boilerplate.  From this index on, things are data-dependent.  */
+#define VX  2
+
 static bool
 buildjoin (char const *initialfile)
 /* Merge pairs of elements in ‘joinlist’ into ‘initialfile’.
@@ -321,7 +316,7 @@ buildjoin (char const *initialfile)
 {
   char const *rev2, *rev3;
   int i;
-  char const *cov[10], *mergev[11];
+  char const *cov[8 + VX], *mergev[11];
   char const **p;
   size_t len;
   char const *subs = NULL;
@@ -330,8 +325,8 @@ buildjoin (char const *initialfile)
   rev3 = maketemp (3);      /* ‘buildrevision’ may use 1 and 2 */
 
   cov[1] = PEER_CO ();
-  /* ‘cov[2]’ setup below.  */
-  p = &cov[3];
+  /* ‘cov[VX]’ setup below.  */
+  p = &cov[1 + VX];
   if (expandarg)
     *p++ = expandarg;
   if (suffixarg)
@@ -362,12 +357,12 @@ buildjoin (char const *initialfile)
         }
       diagnose ("revision %s", joinlist[i]);
       ACCF ("-p%s", joinlist[i]);
-      cov[2] = finish_string (SINGLE, &len);
+      cov[VX] = finish_string (SINGLE, &len);
       if (runv (-1, rev2, cov))
         goto badmerge;
       diagnose ("revision %s", joinlist[i + 1]);
       ACCF ("-p%s", joinlist[i + 1]);
-      cov[2] = finish_string (SINGLE, &len);
+      cov[VX] = finish_string (SINGLE, &len);
       if (runv (-1, rev3, cov))
         goto badmerge;
       diagnose ("merging...");
@@ -394,43 +389,6 @@ badmerge:
   return false;
 }
 
-/*:help
-[options] file ...
-Options:
-  -f[REV]       Force overwrite of working file.
-  -I[REV]       Interactive.
-  -p[REV]       Write to stdout instead of the working file.
-  -q[REV]       Quiet mode.
-  -r[REV]       Normal checkout.
-  -l[REV]       Like -r, but also lock.
-  -u[REV]       Like -l, but unlock.
-  -M[REV]       Reset working file mtime (relevant for -l, -u).
-  -kSUBST       Use SUBST substitution, one of: kv, kvl, k, o, b, v.
-  -dDATE        Select latest before or on DATE.
-  -jJOINS       Merge using JOINS, a list of REV:REV pairs;
-                this option is obsolete -- see rcsmerge(1).
-  -sSTATE       Select matching state STATE.
-  -T            Preserve the modification time on the RCS file
-                even if it changes because a lock is added or removed.
-  -wWHO         Select matching login WHO.
-  -V            Like --version.
-  -VN           Emulate RCS version N.
-  -xSUFF        Specify SUFF as a slash-separated list of suffixes
-                used to identify RCS file names.
-  -zZONE        Specify date output format in keyword-substitution
-                and also the default timezone for -dDATE.
-
-Multiple flags in {fIlMpqru} may be used, except for -r, -l, -u, which are
-mutually exclusive.  If specified, REV can be symbolic, numeric, or mixed:
-  symbolic -- must have been defined previously (see ci(1))
-  $        -- determine the revision number from keyword values
-              in the working file
-  .N       -- prepend default branch => DEFBR.N
-  BR.N     -- use this
-  BR       -- latest revision on branch BR
-If REV is omitted, take it to be the latest on the default branch.
-*/
-
 int
 main (int argc, char **argv)
 {
@@ -450,8 +408,8 @@ main (int argc, char **argv)
     {
       .invoke = argv[0],
       .name = "co",
-      .help = help,
-      .exiterr = exiterr
+      .help = co_help,
+      .tyag = BOG_FULL
     };
 
   CHECK_HV ();
@@ -795,4 +753,41 @@ main (int argc, char **argv)
   return exitstatus;
 }
 
+/*:help
+[options] file ...
+Options:
+  -f[REV]       Force overwrite of working file.
+  -I[REV]       Interactive.
+  -p[REV]       Write to stdout instead of the working file.
+  -q[REV]       Quiet mode.
+  -r[REV]       Normal checkout.
+  -l[REV]       Like -r, but also lock.
+  -u[REV]       Like -l, but unlock.
+  -M[REV]       Reset working file mtime (relevant for -l, -u).
+  -kSUBST       Use SUBST substitution, one of: kv, kvl, k, o, b, v.
+  -dDATE        Select latest before or on DATE.
+  -jJOINS       Merge using JOINS, a list of REV:REV pairs;
+                this option is obsolete -- see rcsmerge(1).
+  -sSTATE       Select matching state STATE.
+  -T            Preserve the modification time on the RCS file
+                even if it changes because a lock is added or removed.
+  -wWHO         Select matching login WHO.
+  -V            Like --version.
+  -VN           Emulate RCS version N.
+  -xSUFF        Specify SUFF as a slash-separated list of suffixes
+                used to identify RCS file names.
+  -zZONE        Specify date output format in keyword-substitution
+                and also the default timezone for -dDATE.
+
+Multiple flags in {fIlMpqru} may be used, except for -r, -l, -u, which are
+mutually exclusive.  If specified, REV can be symbolic, numeric, or mixed:
+  symbolic -- must have been defined previously (see ci(1))
+  $        -- determine the revision number from keyword values
+              in the working file
+  .N       -- prepend default branch => DEFBR.N
+  BR.N     -- use this
+  BR       -- latest revision on branch BR
+If REV is omitted, take it to be the latest on the default branch.
+*/
+
 /* co.c ends here */
