@@ -1,6 +1,6 @@
 /* Identify RCS keyword strings in files.
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -28,12 +28,6 @@
 
 struct top *top;
 
-static exiting void
-exiterr (void)
-{
-  exit_failurefully ();
-}
-
 static int
 match (register FILE *fp)
 /* Group substring between two KDELIM's; then do pattern match.  */
@@ -123,25 +117,16 @@ scanfile (register FILE *file, char const *name)
     {
       syserror_errno (name);
       /* The following is equivalent to ‘exit (EXIT_FAILURE)’, but we
-         invoke ‘exiterr’ to keep lint happy.  The DOS and OS/2 ports
-         need ‘exiterr’.  */
+         invoke ‘BOW_OUT’ to keep lint, as well as the DOS and OS/2 ports
+         happy.  [Is this still relevant? --ttn]  */
       fflush (stdout);
-      exiterr ();
+      BOW_OUT ();
     }
   if (!BE (quiet))
     complain ("%s warning: no id keywords in %s\n", PROGRAM (name), name);
   return 0;
 }
 
-/*:help
-[options] [file ...]
-Options:
-  -q            Suppress warnings if no patterns are found.
-  -V            Like --version.
-
-If no FILE is specified, scan standard input.
-*/
-
 int
 main (int argc, char **argv)
 {
@@ -152,8 +137,8 @@ main (int argc, char **argv)
     {
       .invoke = argv[0],
       .name = "ident",
-      .help = help,
-      .exiterr = exiterr
+      .help = ident_help,
+      .tyag = TYAG_IMMEDIATE
     };
 
   CHECK_HV ();
@@ -204,4 +189,13 @@ main (int argc, char **argv)
   return status;
 }
 
+/*:help
+[options] [file ...]
+Options:
+  -q            Suppress warnings if no patterns are found.
+  -V            Like --version.
+
+If no FILE is specified, scan standard input.
+*/
+
 /* ident.c ends here */
