@@ -1,6 +1,6 @@
-/* merge - three-way file merge
+/* Three-way file merge.
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1991, 1992, 1993, 1994, 1995 Paul Eggert
 
    This file is part of GNU RCS.
@@ -28,26 +28,6 @@
 
 struct top *top;
 
-static exiting void
-exiterr (void)
-{
-  tempunlink ();
-  exit_diff_trouble ();
-}
-
-/*:help
-[options] receiving-sibling parent other-sibling
-Options:
-  -A            Use `diff3 -A' style.
-  -E            Use `diff3 -E' style (default).
-  -e            Use `diff3 -e' style.
-  -p            Write to stdout instead of overwriting RECEIVING-SIBLING.
-  -q            Quiet mode; suppress conflict warnings.
-  -LLABEL       (up to three times) Specify the conflict labels for
-                RECEIVING-SIBLING, PARENT and OTHER-SIBLING, respectively.
-  -V            Like --version.
-*/
-
 int
 main (int argc, char **argv)
 {
@@ -60,8 +40,8 @@ main (int argc, char **argv)
     {
       .invoke = argv[0],
       .name = "merge",
-      .help = help,
-      .exiterr = exiterr
+      .help = merge_help,
+      .tyag = BOG_DIFF
     };
 
   CHECK_HV ();
@@ -120,10 +100,23 @@ main (int argc, char **argv)
     }
 
   if (FLOW (erroneousp))
-    exiterr ();
+    BOW_OUT ();
   exitstatus = merge (tostdout, edarg, three_manifestations);
   gnurcs_goodbye ();
   return exitstatus;
 }
 
+/*:help
+[options] receiving-sibling parent other-sibling
+Options:
+  -A            Use `diff3 -A' style.
+  -E            Use `diff3 -E' style (default).
+  -e            Use `diff3 -e' style.
+  -p            Write to stdout instead of overwriting RECEIVING-SIBLING.
+  -q            Quiet mode; suppress conflict warnings.
+  -LLABEL       (up to three times) Specify the conflict labels for
+                RECEIVING-SIBLING, PARENT and OTHER-SIBLING, respectively.
+  -V            Like --version.
+*/
+
 /* merge.c ends here */
