@@ -1,6 +1,6 @@
 /* Change RCS file attributes.
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -84,15 +84,6 @@ cleanup (void)
   dirtempunlink ();
 }
 
-static exiting void
-exiterr (void)
-{
-  ORCSerror ();
-  dirtempunlink ();
-  tempunlink ();
-  exit_failurefully ();
-}
-
 static void
 getassoclst (struct link **tp, char *sp)
 /* Associate a symbolic name to a revision or branch,
@@ -576,7 +567,7 @@ removerevs (void)
 
   if (delrev.code == 0)
     {                           /* -o rev or -o branch */
-      if (length & 1)
+      if (ODDP (length))
         temp = SEARCH (target->num, length + 1);
       else if (cmp)
         {
@@ -595,7 +586,7 @@ removerevs (void)
       return true;
     }
 
-  if (length & 1)
+  if (ODDP (length))
     {                           /* invalid branch after -o */
       RERR ("invalid branch range %s after -o", numrev.string);
       return false;
@@ -789,7 +780,7 @@ setlock (char const *rev, struct wlink **tp_deltas)
       target = gr_revno (numrev.string, tp_deltas);
       if (target)
         {
-          if (!(countnumflds (numrev.string) & 1)
+          if (EVENP (countnumflds (numrev.string))
               && !NUM_EQ (target->num, numrev.string))
             RERR ("can't lock nonexisting revision %s", numrev.string);
           else
@@ -863,7 +854,7 @@ dolocks (struct wlink **tp_deltas)
         target = gr_revno (numrev.string, tp_deltas);
         if (target)
           {
-            if (!(countnumflds (numrev.string) & 1)
+            if (EVENP (countnumflds (numrev.string))
                 && !NUM_EQ (target->num, numrev.string))
               RERR ("can't unlock nonexisting revision %s", bye);
             else
@@ -926,7 +917,7 @@ rcs_setstate (char const *rev, char const *status,
       target = gr_revno (numrev.string, tp_deltas);
       if (target)
         {
-          if (!(countnumflds (numrev.string) & 1)
+          if (EVENP (countnumflds (numrev.string))
               && !NUM_EQ (target->num, numrev.string))
             RERR ("can't set state of nonexisting revision %s", numrev.string);
           else if (STR_DIFF (target->state, status))
@@ -1051,48 +1042,6 @@ buildtree (void)
   return;
 }
 
-/*:help
-[options] file ...
-Options:
-  -i              Create and initialize a new RCS file.
-  -L              Set strict locking.
-  -U              Set non-strict locking.
-  -M              Don't send mail when breaking someone else's lock.
-  -T              Preserve the modification time on the
-                  RCS file unless a revision is removed.
-  -I              Interactive.
-  -q              Quiet mode.
-  -aLOGINS        Append LOGINS (comma-separated) to access-list.
-  -e[LOGINS]      Erase LOGINS (all if unspecified) from access-list.
-  -AFILENAME      Append access-list of FILENAME to current access-list.
-  -b[REV]         Set default branch to that of REV or
-                  highest branch on trunk if REV is omitted.
-  -l[REV]         Lock revision REV.
-  -u[REV]         Unlock revision REV.
-  -cSTRING        Set comment leader to STRING; don't use: obsolete.
-  -kSUBST         Set default keyword substitution to SUBST (see co(1)).
-  -mREV:MSG       Replace REV's log message with MSG.
-  -nNAME[:[REV]]  If :REV is omitted, delete symbolic NAME.
-                  Otherwise, associate NAME with REV; NAME must be new.
-  -NNAME[:[REV]]  Like -n, but overwrite any previous assignment.
-  -oRANGE         Outdate revisions in RANGE:
-                    REV       -- single revision
-                    BR        -- latest revision on branch BR
-                    REV1:REV2 -- REV1 to REV2 on same branch
-                    :REV      -- beginning of branch to REV
-                    REV:      -- REV to end of branch
-  -sSTATE[:REV]   Set state of REV to STATE.
-  -t-TEXT         Set description in RCS file to TEXT.
-  -tFILENAME      Set description in RCS file to contents of FILENAME.
-  -V              Like --version.
-  -VN             Emulate RCS version N.
-  -xSUFF          Specify SUFF as a slash-separated list of suffixes
-                  used to identify RCS file names.
-  -zZONE          No effect; included for compatibility with other commands.
-
-REV defaults to the latest revision on the default branch.
-*/
-
 int
 main (int argc, char **argv)
 {
@@ -1112,8 +1061,8 @@ main (int argc, char **argv)
     {
       .invoke = argv[0],
       .name = "rcs",
-      .help = help,
-      .exiterr = exiterr
+      .help = rcs_help,
+      .tyag = BOG_FULL
     };
 
   CHECK_HV ();
@@ -1552,4 +1501,46 @@ main (int argc, char **argv)
   return exitstatus;
 }
 
+/*:help
+[options] file ...
+Options:
+  -i              Create and initialize a new RCS file.
+  -L              Set strict locking.
+  -U              Set non-strict locking.
+  -M              Don't send mail when breaking someone else's lock.
+  -T              Preserve the modification time on the
+                  RCS file unless a revision is removed.
+  -I              Interactive.
+  -q              Quiet mode.
+  -aLOGINS        Append LOGINS (comma-separated) to access-list.
+  -e[LOGINS]      Erase LOGINS (all if unspecified) from access-list.
+  -AFILENAME      Append access-list of FILENAME to current access-list.
+  -b[REV]         Set default branch to that of REV or
+                  highest branch on trunk if REV is omitted.
+  -l[REV]         Lock revision REV.
+  -u[REV]         Unlock revision REV.
+  -cSTRING        Set comment leader to STRING; don't use: obsolete.
+  -kSUBST         Set default keyword substitution to SUBST (see co(1)).
+  -mREV:MSG       Replace REV's log message with MSG.
+  -nNAME[:[REV]]  If :REV is omitted, delete symbolic NAME.
+                  Otherwise, associate NAME with REV; NAME must be new.
+  -NNAME[:[REV]]  Like -n, but overwrite any previous assignment.
+  -oRANGE         Outdate revisions in RANGE:
+                    REV       -- single revision
+                    BR        -- latest revision on branch BR
+                    REV1:REV2 -- REV1 to REV2 on same branch
+                    :REV      -- beginning of branch to REV
+                    REV:      -- REV to end of branch
+  -sSTATE[:REV]   Set state of REV to STATE.
+  -t-TEXT         Set description in RCS file to TEXT.
+  -tFILENAME      Set description in RCS file to contents of FILENAME.
+  -V              Like --version.
+  -VN             Emulate RCS version N.
+  -xSUFF          Specify SUFF as a slash-separated list of suffixes
+                  used to identify RCS file names.
+  -zZONE          No effect; included for compatibility with other commands.
+
+REV defaults to the latest revision on the default branch.
+*/
+
 /* rcs.c ends here */
