@@ -1,6 +1,6 @@
 /* Clean up working files.
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1991, 1992, 1993, 1994, 1995 Paul Eggert
 
    This file is part of GNU RCS.
@@ -51,15 +51,6 @@ cleanup (void)
   dirtempunlink ();
 }
 
-static exiting void
-exiterr (void)
-{
-  ORCSerror ();
-  dirtempunlink ();
-  tempunlink ();
-  exit_failurefully ();
-}
-
 static bool
 unlock (struct delta *delta)
 {
@@ -114,25 +105,6 @@ get_directory (char const *dirname, char ***aargv)
   return entries;
 }
 
-/*:help
-[options] file ...
-Options:
-  -r[REV]       Specify revision.
-  -u[REV]       Unlock if is locked and no differences found.
-  -n[REV]       Dry run (no act, don't operate).
-  -q[REV]       Quiet mode.
-  -kSUBST       Substitute using mode SUBST (see co(1)).
-  -T            Preserve the modification time on the RCS file
-                even if it changes because a lock is removed.
-  -V            Like --version.
-  -VN           Emulate RCS version N.
-  -xSUFF        Specify SUFF as a slash-separated list of suffixes
-                used to identify RCS file names.
-  -zZONE        Specify date output format in keyword-substitution.
-
-REV defaults to the latest revision on the default branch.
-*/
-
 int
 main (int argc, char **argv)
 {
@@ -147,8 +119,8 @@ main (int argc, char **argv)
     {
       .invoke = argv[0],
       .name = "rcsclean",
-      .help = help,
-      .exiterr = exiterr
+      .help = rcsclean_help,
+      .tyag = BOG_FULL
     };
 
   CHECK_HV ();
@@ -341,4 +313,23 @@ main (int argc, char **argv)
   return exitstatus;
 }
 
+/*:help
+[options] file ...
+Options:
+  -r[REV]       Specify revision.
+  -u[REV]       Unlock if is locked and no differences found.
+  -n[REV]       Dry run (no act, don't operate).
+  -q[REV]       Quiet mode.
+  -kSUBST       Substitute using mode SUBST (see co(1)).
+  -T            Preserve the modification time on the RCS file
+                even if it changes because a lock is removed.
+  -V            Like --version.
+  -VN           Emulate RCS version N.
+  -xSUFF        Specify SUFF as a slash-separated list of suffixes
+                used to identify RCS file names.
+  -zZONE        Specify date output format in keyword-substitution.
+
+REV defaults to the latest revision on the default branch.
+*/
+
 /* rcsclean.c ends here */
