@@ -1,6 +1,6 @@
 /* Compare RCS revisions.
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -92,13 +92,6 @@ cleanup (void)
   fro_zclose (&workptr);
 }
 
-static exiting void
-exiterr (void)
-{
-  tempunlink ();
-  exit_diff_trouble ();
-}
-
 #if DIFF_L
 static char const *
 setup_label (char const *num, char const date[datesize])
@@ -107,37 +100,16 @@ setup_label (char const *num, char const date[datesize])
   char datestr[datesize + zonelenmax];
 
   date2str (date, datestr);
-  accf (PLEXUS, "-L%s\t%s", MANI (filename), datestr);
+  accf (PLEXUS, "--label=%s\t%s", MANI (filename), datestr);
   if (num)
     accf (PLEXUS, "\t%s", num);
   return finish_string (PLEXUS, &len);
 }
 #endif
 
-/*:help
-[options] file ...
-Options:
-  -rREV         (zero, one, or two times) Name a revision.
-  -kSUBST       Substitute using mode SUBST (see co(1)).
-  -q            Quiet mode.
-  -V            Like --version.
-  -VN           Emulate RCS version N.
-  -xSUFF        Specify SUFF as a slash-separated list of suffixes
-                used to identify RCS file names.
-  -zZONE        Specify date output format in keyword-substitution.
-
-If given two revisions (-rREV1 -rREV2), compare those revisions.
-If given only one revision (-rREV), compare the working file with it.
-If given no revisions, compare the working file with the latest
-revision on the default branch.
-
-Additionally, the following options (and their argument, if any) are
-passed to the underlying diff(1) command:
-  -0, -1, -2, -3, -4, -5, -6, -7, -8, -9, -B, -C, -D, -F, -H, -I,
-  -L, -U, -W, -a, -b, -c, -d, -e, -f, -h, -i, -n, -p, -t, -u, -w, -y,
-  [long options (that start with "--")].
-(Not all of these options are meaningful.)
-*/
+/* Elements in the constructed command line prior to this index are
+   boilerplate.  From this index on, things are data-dependent.  */
+#define COMMAND_LINE_VARYING  (3 + !DIFF_L)
 
 int
 main (int argc, char **argv)
@@ -151,7 +123,7 @@ main (int argc, char **argv)
   char const **diff_label1, **diff_label2;
   char date2[datesize];
 #endif
-  char const *cov[10 + !DIFF_L];
+  char const *cov[7 + COMMAND_LINE_VARYING];
   char const **diffv, **diffp, **diffpend;      /* argv for subsidiary diff */
   char const **pp, *diffvstr = NULL;
   struct cbuf commarg;
@@ -163,8 +135,8 @@ main (int argc, char **argv)
     {
       .invoke = argv[0],
       .name = "rcsdiff",
-      .help = help,
-      .exiterr = exiterr
+      .help = rcsdiff_help,
+      .tyag = BOG_DIFF
     };
 
   CHECK_HV ();
@@ -332,7 +304,7 @@ main (int argc, char **argv)
   cov[1] = PEER_CO ();
   cov[2] = "-q";
 #if !DIFF_L
-  cov[3] = "-M";
+  cov[COMMAND_LINE_VARYING - 1] = "-M";
 #endif
 
   /* Now handle all filenames.  */
@@ -421,7 +393,7 @@ main (int argc, char **argv)
 
         commarg = minus_p (xrev1, rev1);
 
-        pp = &cov[3 + !DIFF_L];
+        pp = &cov[COMMAND_LINE_VARYING];
         *pp++ = commarg.string;
         if (lexpandarg)
           *pp++ = lexpandarg;
@@ -457,7 +429,7 @@ main (int argc, char **argv)
         else
           {
             commarg = minus_p (xrev2, rev2);
-            cov[3 + !DIFF_L] = commarg.string;
+            cov[COMMAND_LINE_VARYING] = commarg.string;
             diffp[1] = maketemp (1);
             if (runv (-1, diffp[1], cov))
               {
@@ -487,4 +459,29 @@ main (int argc, char **argv)
   return exitstatus;
 }
 
+/*:help
+[options] file ...
+Options:
+  -rREV         (zero, one, or two times) Name a revision.
+  -kSUBST       Substitute using mode SUBST (see co(1)).
+  -q            Quiet mode.
+  -V            Like --version.
+  -VN           Emulate RCS version N.
+  -xSUFF        Specify SUFF as a slash-separated list of suffixes
+                used to identify RCS file names.
+  -zZONE        Specify date output format in keyword-substitution.
+
+If given two revisions (-rREV1 -rREV2), compare those revisions.
+If given only one revision (-rREV), compare the working file with it.
+If given no revisions, compare the working file with the latest
+revision on the default branch.
+
+Additionally, the following options (and their argument, if any) are
+passed to the underlying diff(1) command:
+  -0, -1, -2, -3, -4, -5, -6, -7, -8, -9, -B, -C, -D, -F, -H, -I,
+  -L, -U, -W, -a, -b, -c, -d, -e, -f, -h, -i, -n, -p, -t, -u, -w, -y,
+  [long options (that start with "--")].
+(Not all of these options are meaningful.)
+*/
+
 /* rcsdiff.c ends here */
