@@ -1,6 +1,6 @@
 /* Extract RCS keyword string values from working files.
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -195,7 +195,7 @@ keeprev (struct fro *fp)
           switch (*sp)
             {
             case 0:
-              if (dotcount & 1)
+              if (ODDP (dotcount))
                 goto done;
               else
                 break;
