@@ -1,6 +1,6 @@
 /* Merge RCS revisions.
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -32,31 +32,6 @@
 
 struct top *top;
 
-static exiting void
-exiterr (void)
-{
-  tempunlink ();
-  exit_diff_trouble ();
-}
-
-/*:help
-[options] file
-Options:
-  -p[REV]       Write to stdout instead of overwriting the working file.
-  -q[REV]       Quiet mode.
-  -rREV         (one or two times) specify a revision.
-  -kSUBST       Substitute using mode SUBST (see co(1)).
-  -V            Like --version.
-  -VN           Emulate RCS version N.
-  -xSUFF        Specify SUFF as a slash-separated list of suffixes
-                used to identify RCS file names.
-  -zZONE        Specify date output format in keyword-substitution.
-
-One or two revisions must be specified (using -p, -q, or -r).
-If only one is specified, use the latest revision on the default
-branch to be the second revision.
-*/
-
 #define quietarg  "-q"
 
 int
@@ -75,8 +50,8 @@ main (int argc, char **argv)
     {
       .invoke = argv[0],
       .name = "rcsmerge",
-      .help = help,
-      .exiterr = exiterr
+      .help = rcsmerge_help,
+      .tyag = BOG_DIFF
     };
 
   CHECK_HV ();
@@ -235,4 +210,22 @@ main (int argc, char **argv)
   return exitstatus;
 }
 
+/*:help
+[options] file
+Options:
+  -p[REV]       Write to stdout instead of overwriting the working file.
+  -q[REV]       Quiet mode.
+  -rREV         (one or two times) specify a revision.
+  -kSUBST       Substitute using mode SUBST (see co(1)).
+  -V            Like --version.
+  -VN           Emulate RCS version N.
+  -xSUFF        Specify SUFF as a slash-separated list of suffixes
+                used to identify RCS file names.
+  -zZONE        Specify date output format in keyword-substitution.
+
+One or two revisions must be specified (using -p, -q, or -r).
+If only one is specified, use the latest revision on the default
+branch to be the second revision.
+*/
+
 /* rcsmerge.c ends here */
