@@ -1,6 +1,6 @@
 /* RCS utility functions
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -38,24 +38,44 @@
 #include "b-isr.h"
 #include "gnu-h-v.h"
 #include "maketime.h"
+#include "progname.h"
 
-void
-exit_failurefully (void)
-{
-  _Exit (EXIT_FAILURE);
-}
+/* Unfortunately, using ‘_Exit’ makes coverage analysis
+   (via ‘gcc --coverage’) difficult since the coverage
+   machinery writes the .gcda files only on ‘exit’.
+   Hence this hair.  */
+#ifdef USE_NORMAL_EXIT
+#ifdef _Exit
+#undef _Exit
+#endif
+#define _Exit(x)  exit (x)
+#endif  /* defined USE_NORMAL_EXIT */
 
-void
+static void
 exit_diff_trouble (void)
 {
   _Exit (DIFF_TROUBLE);
 }
 
+exiting void
+thank_you_and_goodnight (int const how)
+{
+  if (how & TYAG_ORCSERROR)
+    ORCSerror ();
+  if (how & TYAG_DIRTMPUNLINK)
+    dirtempunlink ();
+  if (how & TYAG_TEMPUNLINK)
+    tempunlink ();
+  _Exit ((how & TYAG_DIFF)
+         ? DIFF_FAILURE
+         : EXIT_FAILURE);
+}
+
 void
 gnurcs_init (struct program const *program)
 {
-  /* Apparently gnulib needs this, sigh.  */
-  program_name = (char *) program->name;
+  /* Help gnulib DTRT.  */
+  set_program_name (program->invoke);
 
   PLEXUS = make_space ("plexus");
   SINGLE = make_space ("single");
