@@ -1,6 +1,6 @@
 /* Print log messages and other information about RCS files.
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
    Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995 Paul Eggert
    Copyright (C) 1982, 1988, 1989 Walter Tichy
 
@@ -83,12 +83,6 @@ cleanup (void)
   fro_zclose (&FLOW (from));
 }
 
-static exiting void
-exiterr (void)
-{
-  exit_failurefully ();
-}
-
 static void
 getlocker (char *argv)
 /* Get the login names of lockers from command line
@@ -302,7 +296,7 @@ extractdelta (struct delta const *pdelta)
       struct revrange const *rr = ls->entry;
 
       length = rr->nfield;
-      if (countnumflds (pdelta->num) == length + (length & 1)
+      if (countnumflds (pdelta->num) == length + ODDP (length)
           && 0 <= compartial (pdelta->num, rr->beg, length)
           && 0 <= compartial (rr->end, pdelta->num, length))
         break;
@@ -476,7 +470,6 @@ extdate (struct delta *root)
         {
           r = ls->entry;
           oep = r->oep;
-          complain ("HEY: %d [%s] [%s] [%s] => ", oep, r->beg, root->date, r->end);
           if ((sel = ((!r->beg[0]
                        || (oep
                            ? DATE_LT (r->beg, root->date)
@@ -486,11 +479,7 @@ extdate (struct delta *root)
                        || (oep
                            ? DATE_LT (root->date, r->end)
                            : !DATE_GT (root->date, r->end))))))
-            {
-              complain ("yes!\n");
-              break;
-            }
-          complain ("no\n");
+            break;
         }
       if (!sel)
         {
@@ -736,38 +725,6 @@ putrevpairs (char const *b, char const *e, bool sawsep)
   PUSH (rr, revlist);
 }
 
-/*:help
-[options] file ...
-Options:
-  -L            Ignore RCS files with no locks set.
-  -R            Print the RCS file name only.
-  -h            Print only the "header" information.
-  -t            Like -h, but also include the description.
-  -N            Omit symbolic names.
-  -b            Select the default branch.
-  -dDATES       Select revisions in the range DATES, with spec:
-                  D      -- single revision D or earlier
-                  D1<D2  -- between D1 and D2, exclusive
-                  D2>D1  -- likewise
-                  <D, D> -- before D
-                  >D, D< -- after D
-                Use <= or >= to make ranges inclusive; DATES
-                may also be a list of semicolon-separated specs.
-  -l[WHO]       Select revisions locked by WHO (comma-separated list)
-                only, or by anyone if WHO is omitted.
-  -r[REVS]      Select revisions in REVS, a comma-separated list of
-                range specs, one of: REV, REV:, :REV, REV1:REV2
-  -sSTATES      Select revisions with state in STATES (comma-separated list).
-  -w[WHO]       Select revisions commited by WHO (comma-separated list),
-                or by the user if WHO is omitted.
-  -V            Like --version.
-  -VN           Emulate RCS version N.
-  -xSUFF        Specify SUFF as a slash-separated list of suffixes
-                used to identify RCS file names.
-  -zZONE        Specify date output format in keyword-substitution.
-  -q            No effect, included for consistency with other commands.
-*/
-
 int
 main (int argc, char **argv)
 {
@@ -785,8 +742,8 @@ main (int argc, char **argv)
     {
       .invoke = argv[0],
       .name = "rlog",
-      .help = help,
-      .exiterr = exiterr
+      .help = rlog_help,
+      .tyag = TYAG_IMMEDIATE
     };
 
   CHECK_HV ();
@@ -1030,4 +987,36 @@ main (int argc, char **argv)
   return exitstatus;
 }
 
+/*:help
+[options] file ...
+Options:
+  -L            Ignore RCS files with no locks set.
+  -R            Print the RCS file name only.
+  -h            Print only the "header" information.
+  -t            Like -h, but also include the description.
+  -N            Omit symbolic names.
+  -b            Select the default branch.
+  -dDATES       Select revisions in the range DATES, with spec:
+                  D      -- single revision D or earlier
+                  D1<D2  -- between D1 and D2, exclusive
+                  D2>D1  -- likewise
+                  <D, D> -- before D
+                  >D, D< -- after D
+                Use <= or >= to make ranges inclusive; DATES
+                may also be a list of semicolon-separated specs.
+  -l[WHO]       Select revisions locked by WHO (comma-separated list)
+                only, or by anyone if WHO is omitted.
+  -r[REVS]      Select revisions in REVS, a comma-separated list of
+                range specs, one of: REV, REV:, :REV, REV1:REV2
+  -sSTATES      Select revisions with state in STATES (comma-separated list).
+  -w[WHO]       Select revisions checked in by WHO (comma-separated list),
+                or by the user if WHO is omitted.
+  -V            Like --version.
+  -VN           Emulate RCS version N.
+  -xSUFF        Specify SUFF as a slash-separated list of suffixes
+                used to identify RCS file names.
+  -zZONE        Specify date output format in keyword-substitution.
+  -q            No effect, included for consistency with other commands.
+*/
+
 /* rlog.c ends here */
