@@ -1,6 +1,6 @@
 /* btdt.c --- been there done that
 
-   Copyright (C) 2010, 2011 Thien-Thi Nguyen
+   Copyright (C) 2010-2012 Thien-Thi Nguyen
 
    This file is part of GNU RCS.
 
@@ -34,20 +34,12 @@
 
 struct top *top;
 
-exiting void
-bow_out (void)
-{
-  dirtempunlink ();
-  tempunlink ();
-  exit_failurefully ();
-}
-
 exiting void
 bad_args (char const *argv0)
 {
   fprintf (stderr, "%s: bad args (try %s --help)\n",
            argv0, PROGRAM (invoke));
-  exit_failurefully ();
+  _Exit (EXIT_FAILURE);
 }
 
 #define MORE "\n\t\t"
@@ -182,7 +174,7 @@ main (int argc, char *argv[argc])
   if (STR_SAME ("--version", argv[1]))
     {
       printf ("btdt (%s) %s\n", PACKAGE_NAME, PACKAGE_VERSION);
-      printf ("Copyright (C) 2010, 2011 Thien-Thi Nguyen\n");
+      printf ("Copyright (C) 2010-2012 Thien-Thi Nguyen\n");
       printf ("License GPLv3+; GNU GPL version 3 or later"
               " <http://gnu.org/licenses/gpl.html>\n\n");
       argv[1] = "--help";
@@ -197,7 +189,9 @@ main (int argc, char *argv[argc])
           {
             .invoke = me,
             .name  = argv[1],
-            .exiterr = yeah[i].scramp ? exit_failurefully : bow_out
+            .tyag = (yeah[i].scramp
+                     ? TYAG_IMMEDIATE
+                     : BOG_ZONK)
           };
 
         gnurcs_init (&program);
